/**
 * Introduction
 *
 * @title ROV - Easy applications from C
 *
 * @copyright Jason Tribbeck / 7th ARM 1994-2001
 *
 * @authors Jason Tribbeck
 *
 * @file drawrender.h
 *
 * @type helper
 *
 * @description
 *
 * The drawrender helper displays a drawfile on the screen. As it performs
 * its own rendering, it does not use the DrawFile module. This also limits
 * its capabilities, and may not render drawfiles correctly.
 */

#ifndef __rov_drawrender
#define __rov_drawrender


#ifdef __cplusplus
extern "C"
{
#endif

/**
 * Renders a drawfile on the canvas
 * @param file_ptr the pointer to the DrawFile.
 * @param file_size the size of the DrawFile.
 * @param ox the offset to the left hand side of the DrawFile (canvas coordinates).
 * @param oy the offset to the bottom of the DrawFile (canvas coordinates).
 * @param x0 the left hand bounding box redraw area.
 * @param y0 the bottom bounding box redraw area.
 * @param x1 the right hand bounding box redraw area.
 * @param y1 the top bounding box redraw area.
 * @param xs the x scale.
 * @param ys the y scale.
 * @note Certain packages (notably Artworks) are known not to compute the bounding 
 * box correctly, and these may have redraw problems.
 * @see drawrender_xsize()
 * @see drawrender_ysize()
 */
void drawrender_render(void *file_ptr,
		       int file_size,
		       int ox,
		       int oy,
		       int x0,
		       int y0,
		       int x1,
		       int y1,
		       double xs,
		       double ys);

/**
 * Gives the x size of the DrawFile.
 * @param file_ptr the pointer to the DrawFile.
 * @param xs the x scale.
 * @note Certain packages (notably Artworks) are known not to compute the bounding 
 * box correctly, and these may return incorrect values.
 * @see drawrender_ysize()
 */
int drawrender_xsize(void *file_ptr,
		     double xs);

/**
 * Gives the y size of the DrawFile.
 * @param file_ptr the pointer to the DrawFile.
 * @param ys the y scale.
 * @note Certain packages (notably Artworks) are known not to compute the bounding 
 * box correctly, and these may return incorrect values.
 * @see drawrender_xsize()
 */
int drawrender_ysize(void *file_ptr,
		     double ys);


#ifdef __cplusplus
}
#endif

#endif
